package main

import (
	"encoding/json"
	"fmt"
)

func main() {
	// 序列号数据
	cities := []string{"shanghai", "郑州", "shangqiu"}
	bs, err := json.Marshal(cities)
	if err != nil {
		fmt.Println(err.Error())
		return
	}
	fmt.Println(bs)         // [91 34 115 104 97 110 103 104 97 105 34 44 34 233 131 145 229 183 158 34 44 34 115 104 97 110 103 113 105 117 34 93]
	fmt.Println(string(bs)) // ["shanghai","郑州","shangqiu"]

	// 反序列化数组
	var c2 []string
	err = json.Unmarshal(bs, &c2)
	if err != nil {
		fmt.Println(err.Error())
		return
	}
	fmt.Printf("%#v\n", c2) // []string{"shanghai", "郑州", "shangqiu"}

	// 序列化映射
	cityMap := map[string]string{"shanghai": "021", "zhengzhou": "0371", "shangqiu": "0370"}
	bs, err = json.Marshal(cityMap)
	fmt.Println(string(bs)) // {"shanghai":"021","shangqiu":"0370","zhengzhou":"0371"}

	// 反序列化映射
	var cm2 map[string]string
	err = json.Unmarshal(bs, &cm2)
	fmt.Printf("%#v\n", cm2) // map[string]string{"shanghai":"021", "shangqiu":"0370", "zhengzhou":"0371"}

	// 缩进输出映射
	bs, err = json.MarshalIndent(cityMap, "", "  ")
	if err != nil {
		fmt.Println(err.Error())
		return
	}
	fmt.Println(string(bs))
	/*
		{
		  "shanghai": "021",
		  "shangqiu": "0370",
		  "zhengzhou": "0371"
		}
	*/

	// 是否可以转化验证
	fmt.Println(json.Valid([]byte("[]"))) // true
	fmt.Println(json.Valid([]byte("[{"))) // false
}
